@@ -3,7 +3,7 @@ function(
 	file=dir(),
 	directory=getwd(),
 	origin=logOrigin(file,directory),
-	reviewer=Sys.info()['login'],
+	reviewer=Sys.info()['user'],
 	force=FALSE,
 	...
 ){
